/*
 * Copyright © 2007 Novell, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 *
 * Author: David Reveman <davidr@novell.com>
 */

#include "compiz-kcfg.h"
#include "page-include.h"

#include <qvbox.h>

#include <kaboutdata.h>
#include <kapplication.h>
#include <kcmdlineargs.h>
#include <kconfigdialog.h>

#define PAGE(pageName) \
    addPage (dialog, new Page_ ## pageName (0), #pageName);

void
addPage (KConfigDialog *dialog,
	 QWidget       *page,
	 const char    *name)
{
    QScrollView *viewer = new QScrollView (0);
    QVBox	*vbox = new QVBox (0);

    page->reparent (vbox, QPoint (0, 0), true);

    viewer->setResizePolicy (QScrollView::AutoOneFit);
    viewer->setFrameStyle (QFrame::NoFrame);
    viewer->addChild (vbox);

    dialog->addPage (viewer, name, page->className (), page->name ());
}

int
main (int argc, char **argv)
{
    KAboutData    aboutData ("compiz", "Compiz", "0.1");
    KConfigDialog *dialog;

    aboutData.addAuthor ("David Reveman", 0, "davidr@novell.com" );

    KCmdLineArgs::init (argc, argv, &aboutData);

    KApplication app;
    CompizKcfg   config ("0");

    config.readConfig ();

    dialog = new KConfigDialog (0, "settings", &config);

#include "page-impl.h"

    app.setMainWidget (dialog);

    dialog->show ();

    return app.exec ();
}
