<!--
    Copyright © 2007 Novell, Inc.

    Permission to use, copy, modify, distribute, and sell this software
    and its documentation for any purpose is hereby granted without
    fee, provided that the above copyright notice appear in all copies
    and that both that copyright notice and this permission notice
    appear in supporting documentation, and that the name of
    Novell, Inc. not be used in advertising or publicity pertaining to
    distribution of the software without specific, written prior permission.
    Novell, Inc. makes no representations about the suitability of this
    software for any purpose. It is provided "as is" without express or
    implied warranty.

    NOVELL, INC. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
    INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN
    NO EVENT SHALL NOVELL, INC. BE LIABLE FOR ANY SPECIAL, INDIRECT OR
    CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
    OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
    NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
    WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

    Author: David Reveman <davidr@novell.com>
  -->

<xsl:stylesheet version='1.0' xmlns:xsl='http://www.w3.org/1999/XSL/Transform'>

  <xsl:output method="xml" indent="yes" omit-xml-declaration="yes"/>

  <xsl:template match="/compiz">
    <UI version="3.2" stdsetdef="1">
      <xsl:variable name="name">
	<xsl:choose>
	  <xsl:when test="/compiz/plugin">
	    <xsl:value-of select="/compiz/plugin/@name"/>
	  </xsl:when>
	  <xsl:otherwise>
	    <xsl:text>core</xsl:text>
	  </xsl:otherwise>
	</xsl:choose>
      </xsl:variable>
      <class>Page_<xsl:value-of select="$name"/></class>
      <widget class="QWidget">
        <property name="name">
          <cstring><xsl:value-of select="/compiz/*/short/text()"/></cstring>
        </property>
	<vbox>
	  <xsl:for-each select="/compiz/*/display | /compiz/*/screen">
	    <xsl:variable name="group">
	      <xsl:value-of select="$name"/>
	      <xsl:text>_</xsl:text>
	      <xsl:value-of select="name()"/>
	    </xsl:variable>
	    <widget class="QGroupBox">
              <property name="name">
		<cstring>noname</cstring>
	      </property>
              <property name="title">
		<xsl:choose>
		  <xsl:when test="name() = 'display'">
		    <string><xsl:text>Display</xsl:text></string>
		  </xsl:when>
		  <xsl:otherwise>
		    <string><xsl:text>Screen</xsl:text></string>
		  </xsl:otherwise>
		</xsl:choose>
              </property>
	      <vbox>
		<xsl:for-each select="option[not(@read_only='true') and not(@type='action')]">
		  <xsl:call-template name="print_option">
		    <xsl:with-param name="group" select="$group"/>
		  </xsl:call-template>
		</xsl:for-each>
	      </vbox>
            </widget>
	  </xsl:for-each>
	</vbox>
      </widget>
    </UI>
  </xsl:template>

  <xsl:template name="print_option">
    <xsl:param name="group"/>
    <xsl:variable name="key">
      <xsl:value-of select="$group"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="@name"/>
    </xsl:variable>
    <xsl:choose>
      <xsl:when test="contains('bool, bell', @type)">
	<xsl:call-template name="print_bool_option">
	  <xsl:with-param name="key" select="$key"/>
	</xsl:call-template>
      </xsl:when>
      <xsl:when test="@type = 'int'">
	<xsl:call-template name="print_int_option">
	  <xsl:with-param name="key" select="$key"/>
	</xsl:call-template>
      </xsl:when>
      <xsl:when test="@type = 'float'">
	<xsl:call-template name="print_float_option">
	  <xsl:with-param name="key" select="$key"/>
	</xsl:call-template>
      </xsl:when>
      <xsl:when test="@type = 'list'">
	<xsl:call-template name="print_list_option">
	  <xsl:with-param name="key" select="$key"/>
	</xsl:call-template>
      </xsl:when>
      <xsl:when test="contains('string, color, key, button, edge, match', @type)">
	<xsl:call-template name="print_string_option">
	  <xsl:with-param name="key" select="$key"/>
	</xsl:call-template>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="print_bool_option">
    <xsl:param name="key"/>
    <widget class="QCheckBox">
      <property name="name">
        <cstring>kcfg_<xsl:value-of select="$key"/></cstring>
      </property>
      <property name="text">
        <string><xsl:value-of select="short[not(@xml:lang)]/text()"/></string>
      </property>
      <property name="whatsThis">
        <string><xsl:value-of select="long[not(@xml:lang)]/text()"/></string>
      </property>
    </widget>
  </xsl:template>

  <xsl:template name="print_int_option">
    <xsl:param name="key"/>
    <hbox>
      <widget class="QLabel">
        <property name="name">
          <cstring>textLabel_<xsl:value-of select="@name"/></cstring>
        </property>
        <property name="text">
          <string><xsl:value-of select="short[not(@xml:lang)]/text()"/>:</string>
        </property>
      </widget>
      <widget class="KIntNumInput">
	<property name="name">
          <cstring>kcfg_<xsl:value-of select="$key"/></cstring>
	</property>
      </widget>
    </hbox>
  </xsl:template>

  <xsl:template name="print_float_option">
    <xsl:param name="key"/>
    <hbox>
      <widget class="QLabel">
        <property name="name">
          <cstring>textLabel_<xsl:value-of select="@name"/></cstring>
        </property>
        <property name="text">
          <string><xsl:value-of select="short[not(@xml:lang)]/text()"/>:</string>
        </property>
      </widget>
      <widget class="KDoubleNumInput">
	<property name="name">
          <cstring>kcfg_<xsl:value-of select="$key"/></cstring>
	</property>
      </widget>
    </hbox>
  </xsl:template>

  <xsl:template name="print_string_option">
    <xsl:param name="key"/>
    <hbox>
      <widget class="QLabel">
	<property name="name">
          <cstring>unnamed</cstring>
	</property>
	<property name="text">
          <string><xsl:value-of select="short[not(@xml:lang)]/text()"/>:</string>
	</property>
      </widget>
      <widget class="QLineEdit">
	<property name="name">
          <cstring>kcfg_<xsl:value-of select="$key"/></cstring>
	</property>
      </widget>
    </hbox>
  </xsl:template>

  <xsl:template name="print_list_option">
    <xsl:param name="key"/>
    <widget class="KEditListBox">
      <property name="name">
        <cstring>kcfg_<xsl:value-of select="$key"/></cstring>
      </property>
      <property name="buttons">
        <set>All</set>
      </property>
	<property name="title">
          <string><xsl:value-of select="short[not(@xml:lang)]/text()"/></string>
	</property>
        <property name="whatsThis">
          <string><xsl:value-of select="long[not(@xml:lang)]/text()"/></string>
        </property>
    </widget>
  </xsl:template>

</xsl:stylesheet>
